@@ -1833,13 +1833,19 @@ FILLER(sys_generic, true)
 	return res;
 }
 
-FILLER(sys_openat_e, true)
+FILLER(sys_openat_x, true)
 {
 	unsigned long flags;
 	unsigned long val;
 	unsigned long mode;
+	long retval;
 	int res;
 
+	retval = bpf_syscall_get_retval(data->ctx);
+	res = bpf_val_to_ring(data, retval);
+	if (res != PPM_SUCCESS)
+		return res;
+
 	/*
 	 * dirfd
 	 */
@@ -3663,6 +3669,64 @@ FILLER(sys_mkdirat_x, true)
 	return res;
 }
 
+FILLER(sys_linkat_x, true)
+{
+	unsigned long val;
+	long retval;
+	int res;
+
+	retval = bpf_syscall_get_retval(data->ctx);
+	res = bpf_val_to_ring(data, retval);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * olddir
+	 */
+	val = bpf_syscall_get_argument(data, 0);
+	if ((int)val == AT_FDCWD)
+		val = PPM_AT_FDCWD;
+
+	res = bpf_val_to_ring(data, val);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * oldpath
+	 */
+	val = bpf_syscall_get_argument(data, 1);
+	res = bpf_val_to_ring(data, val);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * newdir
+	 */
+	val = bpf_syscall_get_argument(data, 2);
+	if ((int)val == AT_FDCWD)
+		val = PPM_AT_FDCWD;
+
+	res = bpf_val_to_ring(data, val);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * newpath
+	 */
+	val = bpf_syscall_get_argument(data, 3);
+	res = bpf_val_to_ring(data, val);
+	if (res != PPM_SUCCESS)
+		return res;
+
+	/*
+	 * flags
+	 */
+	val = bpf_syscall_get_argument(data, 4);
+	res = bpf_val_to_ring(data, linkat_flags_to_scap(val));
+
+	return res;
+}
+
 FILLER(sys_autofill, true)
 {
 	const struct ppm_event_entry *evinfo;
