@@ -55,7 +55,6 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #include <linux/fdtable.h>
 #endif
 #include <net/sock.h>
-#include <asm/asm-offsets.h>	/* For NR_syscalls */
 #include <asm/unistd.h>
 
 #include "driver_config.h"
@@ -755,6 +754,13 @@ cleanup_ioctl_procinfo:
 		}
 		ret = 0;
 		goto cleanup_ioctl_nolock;
+	} else if (cmd == PPM_IOCTL_GET_PROBE_VERSION) {
+		if (copy_to_user((void *)arg, PROBE_VERSION, sizeof(PROBE_VERSION))) {
+			ret = -EINVAL;
+			goto cleanup_ioctl_nolock;
+		}
+		ret = 0;
+		goto cleanup_ioctl_nolock;
 	}
 
 	mutex_lock(&g_consumer_mutex);
@@ -905,7 +911,7 @@ cleanup_ioctl_procinfo:
 
 		vpr_info("PPM_IOCTL_MASK_SET_EVENT (%u), consumer %p\n", syscall_to_set, consumer_id);
 
-		if (syscall_to_set > PPM_EVENT_MAX) {
+		if (syscall_to_set >= PPM_EVENT_MAX) {
 			pr_err("invalid syscall %u\n", syscall_to_set);
 			ret = -EINVAL;
 			goto cleanup_ioctl;
@@ -922,7 +928,7 @@ cleanup_ioctl_procinfo:
 
 		vpr_info("PPM_IOCTL_MASK_UNSET_EVENT (%u), consumer %p\n", syscall_to_unset, consumer_id);
 
-		if (syscall_to_unset > NR_syscalls) {
+		if (syscall_to_unset >= PPM_EVENT_MAX) {
 			pr_err("invalid syscall %u\n", syscall_to_unset);
 			ret = -EINVAL;
 			goto cleanup_ioctl;
@@ -1666,6 +1672,7 @@ static int record_event_consumer(struct ppm_consumer_t *consumer,
 		hdr->ts = timespec_to_ns(ts);
 		hdr->tid = current->pid;
 		hdr->type = event_type;
+		hdr->nparams = args.nargs;
 
 		/*
 		 * Populate the parameters for the filler callback
